Class: Google::Apis::VisionV1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::VisionV1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
8991 8992 8993 |
# File 'lib/google/apis/vision_v1/classes.rb', line 8991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
8976 8977 8978 |
# File 'lib/google/apis/vision_v1/classes.rb', line 8976 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::VisionV1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
8981 8982 8983 |
# File 'lib/google/apis/vision_v1/classes.rb', line 8981 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
8989 8990 8991 |
# File 'lib/google/apis/vision_v1/classes.rb', line 8989 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8996 8997 8998 8999 9000 |
# File 'lib/google/apis/vision_v1/classes.rb', line 8996 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |