Class: Google::Apis::VisionV1::ListProductsResponse
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1::ListProductsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb
Overview
Response message for the ListProducts method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more results in the list.
-
#products ⇒ Array<Google::Apis::VisionV1::Product>
List of products.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListProductsResponse
constructor
A new instance of ListProductsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListProductsResponse
Returns a new instance of ListProductsResponse.
9070 9071 9072 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
Token to retrieve the next page of results, or empty if there are no more
results in the list.
Corresponds to the JSON property nextPageToken
9063 9064 9065 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9063 def next_page_token @next_page_token end |
#products ⇒ Array<Google::Apis::VisionV1::Product>
List of products.
Corresponds to the JSON property products
9068 9069 9070 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9068 def products @products end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9075 9076 9077 9078 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9075 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @products = args[:products] if args.key?(:products) end |