Class: Google::Apis::VisionV1::LocationInfo
- Inherits:
-
Object
- Object
- Google::Apis::VisionV1::LocationInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb
Overview
Detected entity location information.
Instance Attribute Summary collapse
-
#lat_lng ⇒ Google::Apis::VisionV1::LatLng
An object that represents a latitude/longitude pair.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocationInfo
constructor
A new instance of LocationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocationInfo
Returns a new instance of LocationInfo.
9168 9169 9170 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#lat_lng ⇒ Google::Apis::VisionV1::LatLng
An object that represents a latitude/longitude pair. This is expressed as a
pair of doubles to represent degrees latitude and degrees longitude. Unless
specified otherwise, this object must conform to the WGS84 standard. Values
must be within normalized ranges.
Corresponds to the JSON property latLng
9166 9167 9168 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9166 def lat_lng @lat_lng end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9173 9174 9175 |
# File 'lib/google/apis/vision_v1/classes.rb', line 9173 def update!(**args) @lat_lng = args[:lat_lng] if args.key?(:lat_lng) end |