Class: Google::Apis::VisionV1::Position

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb

Overview

A 3D position in the image, used primarily for Face detection landmarks. A valid Position must have both x and y coordinates. The position coordinates are in the same scale as the original image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Position

Returns a new instance of Position.



9469
9470
9471
# File 'lib/google/apis/vision_v1/classes.rb', line 9469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#xFloat

X coordinate. Corresponds to the JSON property x

Returns:

  • (Float)


9457
9458
9459
# File 'lib/google/apis/vision_v1/classes.rb', line 9457

def x
  @x
end

#yFloat

Y coordinate. Corresponds to the JSON property y

Returns:

  • (Float)


9462
9463
9464
# File 'lib/google/apis/vision_v1/classes.rb', line 9462

def y
  @y
end

#zFloat

Z coordinate (or depth). Corresponds to the JSON property z

Returns:

  • (Float)


9467
9468
9469
# File 'lib/google/apis/vision_v1/classes.rb', line 9467

def z
  @z
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9474
9475
9476
9477
9478
# File 'lib/google/apis/vision_v1/classes.rb', line 9474

def update!(**args)
  @x = args[:x] if args.key?(:x)
  @y = args[:y] if args.key?(:y)
  @z = args[:z] if args.key?(:z)
end