Class: Google::Apis::VisionV1::ProductSearchResults

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb

Overview

Results for a product search request.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProductSearchResults

Returns a new instance of ProductSearchResults.



9611
9612
9613
# File 'lib/google/apis/vision_v1/classes.rb', line 9611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#index_timeString

Timestamp of the index which provided these results. Products added to the product set and products removed from the product set after this time are not reflected in the current results. Corresponds to the JSON property indexTime

Returns:

  • (String)


9596
9597
9598
# File 'lib/google/apis/vision_v1/classes.rb', line 9596

def index_time
  @index_time
end

#product_grouped_resultsArray<Google::Apis::VisionV1::GroupedResult>

List of results grouped by products detected in the query image. Each entry corresponds to one bounding polygon in the query image, and contains the matching products specific to that region. There may be duplicate product matches in the union of all the per-product results. Corresponds to the JSON property productGroupedResults



9604
9605
9606
# File 'lib/google/apis/vision_v1/classes.rb', line 9604

def product_grouped_results
  @product_grouped_results
end

#resultsArray<Google::Apis::VisionV1::Result>

List of results, one for each product match. Corresponds to the JSON property results

Returns:



9609
9610
9611
# File 'lib/google/apis/vision_v1/classes.rb', line 9609

def results
  @results
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9616
9617
9618
9619
9620
# File 'lib/google/apis/vision_v1/classes.rb', line 9616

def update!(**args)
  @index_time = args[:index_time] if args.key?(:index_time)
  @product_grouped_results = args[:product_grouped_results] if args.key?(:product_grouped_results)
  @results = args[:results] if args.key?(:results)
end