Class: Google::Apis::VisionV1::PurgeProductsRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/vision_v1/classes.rb,
lib/google/apis/vision_v1/representations.rb,
lib/google/apis/vision_v1/representations.rb

Overview

Request message for the PurgeProducts method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PurgeProductsRequest

Returns a new instance of PurgeProductsRequest.



9748
9749
9750
# File 'lib/google/apis/vision_v1/classes.rb', line 9748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delete_orphan_productsBoolean Also known as: delete_orphan_products?

If delete_orphan_products is true, all Products that are not in any ProductSet will be deleted. Corresponds to the JSON property deleteOrphanProducts

Returns:

  • (Boolean)


9733
9734
9735
# File 'lib/google/apis/vision_v1/classes.rb', line 9733

def delete_orphan_products
  @delete_orphan_products
end

#forceBoolean Also known as: force?

The default value is false. Override this value to true to actually perform the purge. Corresponds to the JSON property force

Returns:

  • (Boolean)


9740
9741
9742
# File 'lib/google/apis/vision_v1/classes.rb', line 9740

def force
  @force
end

#product_set_purge_configGoogle::Apis::VisionV1::ProductSetPurgeConfig

Config to control which ProductSet contains the Products to be deleted. Corresponds to the JSON property productSetPurgeConfig



9746
9747
9748
# File 'lib/google/apis/vision_v1/classes.rb', line 9746

def product_set_purge_config
  @product_set_purge_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9753
9754
9755
9756
9757
# File 'lib/google/apis/vision_v1/classes.rb', line 9753

def update!(**args)
  @delete_orphan_products = args[:delete_orphan_products] if args.key?(:delete_orphan_products)
  @force = args[:force] if args.key?(:force)
  @product_set_purge_config = args[:product_set_purge_config] if args.key?(:product_set_purge_config)
end